@@ -175,7 +175,7 @@ static short get_bcd_from_rev_file(char *path)
 		        fclose(fp);
 			return -1;
                 }
-		bcd = ((buf[0] - '0') << 8) | (buf[2] - '0');
+		bcd = ((buf[0] - '0') << 8) | ((buf[2] - '0') << 4);
 
 		fclose(fp);
 	}
@@ -312,7 +312,7 @@ static unsigned int get_variable_supply_pdo(char *path, int src_snk)
 	union libtypec_variable_supply_src var_src;
 	unsigned int tmp;
 
-	var_src.obj_var_sply.type = 1;
+	var_src.obj_var_sply.type = PDO_VARIABLE;
 	
 	snprintf(port_content, sizeof(port_content), "%s/%s", path, "maximum_voltage");
 	tmp = get_dword_from_path(port_content);
@@ -407,6 +407,9 @@ static unsigned int get_fixed_supply_pdo(char *path, int src_snk)
 	
 	unsigned int tmp;
 
+	memset(&fxd_src, 0, sizeof(fxd_src));
+	memset(&fxd_snk, 0, sizeof(fxd_snk));
+
 	if(src_snk)
 	{
 		fxd_src.obj_fixed_sply.type = 0;
@@ -418,7 +421,7 @@ static unsigned int get_fixed_supply_pdo(char *path, int src_snk)
 		fxd_src.obj_fixed_sply.usb_suspend = get_dword_from_path(port_content);
 		
 		snprintf(port_content, sizeof(port_content), "%s/%s", path, "unconstrained_power");
-		fxd_src.obj_fixed_sply.uncons_pwr = get_dword_from_path(path);
+		fxd_src.obj_fixed_sply.uncons_pwr = get_dword_from_path(port_content);
 		
 		snprintf(port_content, sizeof(port_content), "%s/%s", path, "usb_communication_capable");
 		fxd_src.obj_fixed_sply.usb_comm = get_dword_from_path(port_content);
@@ -449,9 +452,12 @@ static unsigned int get_fixed_supply_pdo(char *path, int src_snk)
 		
 		snprintf(port_content, sizeof(port_content), "%s/%s", path, "dual_role_power");
 		fxd_snk.obj_fixed_supply.drp = get_dword_from_path(port_content);
+
+		snprintf(port_content, sizeof(port_content), "%s/%s", path, "higher_capability");
+		fxd_snk.obj_fixed_supply.higher_caps = get_dword_from_path(port_content);
 		
 		snprintf(port_content, sizeof(port_content), "%s/%s", path, "unconstrained_power");
-		fxd_snk.obj_fixed_supply.uncons_pwr = get_dword_from_path(path);
+		fxd_snk.obj_fixed_supply.uncons_pwr = get_dword_from_path(port_content);
 		
 		snprintf(port_content, sizeof(port_content), "%s/%s", path, "usb_communication_capable");
 		fxd_snk.obj_fixed_supply.usb_comm_cap = get_dword_from_path(port_content);
@@ -577,7 +583,7 @@ static int libtypec_sysfs_get_capability_ops(struct libtypec_capability_data *ca
 {
 	DIR *typec_path = opendir(SYSFS_TYPEC_PATH), *port_path;
 	struct dirent *typec_entry, *port_entry;
-	int num_ports = 0, num_alt_mode = 0;
+	int num_ports = 0, num_alt_mode = 0, num_port_alt = 0;
 	char path_str[512], port_content[512 + 64];
 
 	if (!typec_path)
@@ -597,15 +603,19 @@ static int libtypec_sysfs_get_capability_ops(struct libtypec_capability_data *ca
 
 			/*Scan the port capability*/
 			port_path = opendir(path_str);
+			num_port_alt = 0;
 
 			while ((port_entry = readdir(port_path)))
 			{
 
 				if (!(strncmp(port_entry->d_name, "port", 4)) && (strlen(port_entry->d_name) <= MAX_PORT_MODE_STR))
 				{
-					num_alt_mode++;
+					num_port_alt++;
 				}
 			}
+			/*Counting different alt modes supported by the PPM*/
+			if(num_alt_mode < num_port_alt)
+				num_alt_mode = num_port_alt;
 
 			snprintf(port_content, sizeof(port_content), "%s/%s", path_str, "usb_power_delivery_revision");
 
@@ -644,27 +654,25 @@ static int libtypec_sysfs_get_conn_capability_ops(int conn_num, struct libtypec_
 
 	snprintf(port_content, sizeof(port_content), "%s/%s", path_str, "power_role");
 
-	conn_cap_data->opr_mode = get_opr_mode(port_content);
+	conn_cap_data->opr_mode.raw_operationmode = get_opr_mode(port_content);
 
-	if (conn_cap_data->opr_mode == OPR_MODE_DRP_ONLY)
+	if (conn_cap_data->opr_mode.raw_operationmode == OPR_MODE_DRP_ONLY)
 	{
 		conn_cap_data->provider = 1;
 		conn_cap_data->consumer = 1;
 	}
-	else if (conn_cap_data->opr_mode == OPR_MODE_RD_ONLY)
+	else if (conn_cap_data->opr_mode.raw_operationmode == OPR_MODE_RD_ONLY)
 		conn_cap_data->consumer = 1;
 	else
 		conn_cap_data->provider = 1;
 
+	conn_cap_data->opr_mode.raw_operationmode = 1 <<  conn_cap_data->opr_mode.raw_operationmode;
+
 	if (get_os_type() == OS_TYPE_CHROME)
 	{
 		snprintf(port_content, sizeof(port_content), "%s/port%d-partner/%s", path_str, conn_num, "usb_power_delivery_revision");
 
-		conn_cap_data->partner_rev = get_pd_rev(port_content);
-
-		snprintf(port_content, sizeof(port_content), "%s/port%d-cable/%s", path_str, conn_num, "usb_power_delivery_revision");
-
-		conn_cap_data->cable_rev = get_pd_rev(port_content);
+		conn_cap_data->partner_pd_rev = get_pd_rev(port_content);
 	}
 	return 0;
 }
@@ -825,7 +833,7 @@ static int libtypec_sysfs_get_connector_status_ops(int conn_num, struct libtypec
 
 	snprintf(path_str, sizeof(path_str), SYSFS_TYPEC_PATH "/port%d/port%d-partner", conn_num, conn_num);
 
-	conn_sts->connect_sts = (lstat(path_str, &sb) == -1) ? 0 : 1;
+	conn_sts->ConnectStatus = (lstat(path_str, &sb) == -1) ? 0 : 1;
 
 	snprintf(path_str, sizeof(path_str), SYSFS_PSY_PATH "/ucsi-source-psy-USBC000:00%d", conn_num + 1);
 
@@ -864,7 +872,7 @@ static int libtypec_sysfs_get_connector_status_ops(int conn_num, struct libtypec
 
 			max_mw = (cur * volt) / (250 * 1000);
 
-			conn_sts->rdo = ((op_mw << 10)) | (max_mw)&0x3FF;
+			conn_sts->RequestDataObject = ((op_mw << 10)) | (max_mw)&0x3FF;
 		}
 	}
 	return 0;
@@ -981,7 +989,7 @@ static int libtypec_sysfs_get_pd_message_ops(int recipient, int conn_num, int nu
 	return 0;
 }
 
-static int libtypec_sysfs_get_pdos_ops(int conn_num, int partner, int offset, int *num_pdo, int src_snk, int type, unsigned int *pdo_data)
+static int libtypec_sysfs_get_pdos_ops(int conn_num, int partner, int offset, int *num_pdo, int src_snk, int type, struct libtypec_get_pdos *pdo_data)
 {
 	int num_pdos_read = 0;
 	char path_str[512], port_content[512 + 256];
@@ -1024,22 +1032,22 @@ static int libtypec_sysfs_get_pdos_ops(int conn_num, int partner, int offset, in
 		snprintf(port_content, sizeof(port_content), "%s/%s", path_str,typec_entry->d_name);
 		if(strstr(typec_entry->d_name, "fixed"))
 		{
-			pdo_data[num_pdos_read++] = get_fixed_supply_pdo(port_content,src_snk);
+			pdo_data->pdo[num_pdos_read++] = get_fixed_supply_pdo(port_content,src_snk);
 
 		}
 		else if(strstr(typec_entry->d_name, "variable"))
 		{
-			pdo_data[num_pdos_read++] = get_variable_supply_pdo(port_content,src_snk);
+			pdo_data->pdo[num_pdos_read++] = get_variable_supply_pdo(port_content,src_snk);
 
 		}
 		else if(strstr(typec_entry->d_name, "battery"))
 		{
-			pdo_data[num_pdos_read++] = get_battery_supply_pdo(port_content,src_snk);
+			pdo_data->pdo[num_pdos_read++] = get_battery_supply_pdo(port_content,src_snk);
 
 		}
 		else if(strstr(typec_entry->d_name, "programmable"))
 		{
-			pdo_data[num_pdos_read++] = get_programmable_supply_pdo(port_content,src_snk);
+			pdo_data->pdo[num_pdos_read++] = get_programmable_supply_pdo(port_content,src_snk);
 
 		}
 		
